#!/usr/bin/perl -w

=head1 NAME

TheoryLearnerOrdered.pl 

=head1 SYNOPSIS

TheoryLearnerOrdered.pl LTBSpecFile filestem

=head1 CONTACT

Josef Urban (firstname dot lastname at gmail dot com)

=head1 COPYRIGHT

Copyright (C) 2012-2013 Josef Urban (firstname dot lastname at gmail dot com)

=head1 LICENCE

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

=cut



use strict;
use lib 'script';
use AITP_Data;
use AITP_ProblemIO;
use File::Spec;
use POSIX ':sys_wait_h';

my $MROOT = "/home/mptp/gr/MPTP2/MaLARea";
$MROOT = $ENV{"MLAR_ROOT"} if(exists($ENV{"MLAR_ROOT"}));
my $MBIN = "$MROOT/bin";
my $MSCRIPT = "$MROOT/script";
my $MTMP = "$MROOT/tmp";
my $MTMPAX = "$MROOT/tmp/Axioms";

my @allargs = @ARGV;

my $ltbfile = shift @ARGV;
my $gfilestem = shift @ARGV;

die "At least two arguments required" 
    unless((defined($ltbfile) && defined($gfilestem)));

sub mywarn { print @_; }

sub dprint { } # print @_; }

# used for exiting on SIGUSR1
sub childstopped 
{ 
    dprint "\nChild $$ stopped by parent\n";
    exit(0);
}

$SIG{USR1} = \&childstopped;

sub min { my ($x,$y) = @_; ($x <= $y)? $x : $y }
sub max { my ($x,$y) = @_; ($x <= $y)? $y : $x }


`mkdir -p $MTMPAX`;


#my %grefnr;                 # Ref2Nr hash for references
#my @gnrref;                 # Nr2Ref array for references
#my %grefsyms;     # Ref2Sym hash for each reference array of its symbols
#my %greftrmstd;   # Ref2Sym hash for each reference array of its stdterms (their shared-entry numbers)
#my %greftrmnrm;   # Ref2Sym hash for each reference array of its nrmterms (their share


# possible SZS statuses
sub szs_INIT        ()  { 'Initial' } # system was not run on the problem yet
sub szs_UNKNOWN     ()  { 'Unknown' } # used when system dies
sub szs_THEOREM     ()  { 'Theorem' }
sub szs_COUNTERSAT  ()  { 'CounterSatisfiable' }
sub szs_RESOUT      ()  { 'ResourceOut' }
sub szs_GAVEUP      ()  { 'GaveUp' }   # system exited before the time limit for unknown reason

# maximum lines in a file that we handle
my $gforgetlimit = 50000;# unless(defined($gforgetlimit));

my $gstarttime = time();

my ($gcategory, $gtraining_directory, $gbatches) = AITP_ProblemIO::ReadLTBData($ltbfile); 
# print "$gcategory,$gtraining_directory\n"; use Data; 

my ($gminrefs, $gmincounts) = AITP_Data::DirProofSummary("$gtraining_directory/Solutions"); 

my ($gincludes) = AITP_Data::DirIncludeFiles("$gtraining_directory/Axioms");

# foreach $k (sort keys %$w) { print $k,":",join(",",@{$w->{$k}}),"\n"}

# prepare the training features and refs files, so we can run KNN on them
# we use the new fofshared (fofshared1) so we can update the hashtable
# (\%gref2fla, \%grefnr, \%gsymnr, \%gsymarity, \%grefsyms, \@gnrsym, \@gnrref, \%greftrmstd, \%greftrmnrm);
my ($gref2fla, $grefnr, $gsymnr, $gsymarity, $grefsyms, $gnrsym, $gnrref, $greftrmstd, $greftrmnrm) =
    AITP_Data::PrepareTables($gtraining_directory,$gfilestem);

my %gstdnr = ();
my %gnrmnr = ();

# the CASC24 ltb strategies:
# [featurekind, weighting, knn, slice, protokoll]
my @gLTBstrats =
(
["ful",0,0,0,"protokoll_atpstr_my_37be21ea059a2fcb865621e373a97f33a9d07b12"],
# ["ful",0,0,0,"protokoll_atpstr_my_c284f1f10aedfccc65cdb7d9b1210ef814cb8f1a"],
["std",1,128,128,"protokoll_atpstr_my_88760aa43d575e84b7030b8a6188f74ba5f80dc7"],
["nrm",1,32,128,"protokoll_atpstr_my_d60b37aca40b6e560cee4bde2efc36c05a24873f"],
["lsi",400,48,160,"protokoll_atpstr_my_a74b37f2d8b7e35be554fc999f671188cf40f113"],
["std",2,64,64,"protokoll_atpstr_my_a74b37f2d8b7e35be554fc999f671188cf40f113"],
["nrm",2,256,256,"protokoll_atpstr_my_cfee9ff42189552c6557cda7d36f20820c827219"],
["lsi",400,8,32,"protokoll_atpstr_my_a74b37f2d8b7e35be554fc999f671188cf40f113"],
["nrm",1,32,128,"protokoll_atpstr_my_2d0c1ae7703dba890de879a4f4409a64f9856908"],
["nrm",2,256,256,"protokoll_atpstr_my_2eeaa79326ed674ea9ebfc3531c32ba1feec013b"],
["nrm",1,128,72,"protokoll_atpstr_my_2d0c1ae7703dba890de879a4f4409a64f9856908"],
["nrm",1,48,20,"protokoll_atpstr_my_eba37f91665fc364eeb63558058658ee9a149d9a"],
["std",2,128,128,"protokoll_atpstr_my_8fb389ef013a89e03c1aa87be52b2f151b1819cc"],
["lsi",400,16,16,"protokoll_atpstr_my_fe548d15a6fc730fd350de634ad9d912ae198efd"],
["lsi",400,128,128,"protokoll_atpstr_my_7b674c1081cd73ca6ce34d02596e6f6fd903ac6c"],
["nrm",2,512,512,"protokoll_atpstr_my_7b674c1081cd73ca6ce34d02596e6f6fd903ac6c"],
["std",1,128,128,"protokoll_atpstr_my_2eeaa79326ed674ea9ebfc3531c32ba1feec013b"],
["std",2,128,128,"protokoll_atpstr_my_40306ce1a432dd48c918ac611d77fc5069b2fbc7"],
["lsi",400,32,32,"protokoll_atpstr_my_c13d4886baa4fa2cef7b4f50892895255b04b078"],
["nrm",1,128,72,"protokoll_atpstr_my_a4a4da5778ba9bebf9bc5e616786c7ad501b1af5"],
["std",2,32,32,"protokoll_atpstr_my_9f72062a403172caf26fbe878a32becf1403c276"],
["lsi",400,16,64,"protokoll_atpstr_my_a473e2c35f909af4ba00d9f1a7a8a454a851ed9c"],
["nrm",2,512,512,"protokoll_atpstr_my_cfee9ff42189552c6557cda7d36f20820c827219"],
["nrm",1,512,512,"protokoll_atpstr_my_cfee9ff42189552c6557cda7d36f20820c827219"],
["nrm",1,64,90,"protokoll_atpstr_my_37be21ea059a2fcb865621e373a97f33a9d07b12"],
["lsi",400,128,128,"protokoll_atpstr_my_2af8b399ea0b8c22c6fc1b13069ad80214f9fa8b"],
["lsi",400,128,128,"protokoll_atpstr_my_9fde028f05afb32f97bced19843d73b32d923682"],
["nrm",1,256,256,"protokoll_atpstr_my_d60b37aca40b6e560cee4bde2efc36c05a24873f"],
["nrm",2,512,512,"protokoll_atpstr_my_9f72062a403172caf26fbe878a32becf1403c276"],
["nrm",2,256,256,"protokoll_atpstr_my_37be21ea059a2fcb865621e373a97f33a9d07b12"],
["nrm",1,48,160,"protokoll_atpstr_my_eba37f91665fc364eeb63558058658ee9a149d9a"],
["nrm",1,64,64,"protokoll_atpstr_my_2d0c1ae7703dba890de879a4f4409a64f9856908"],
["nrm",1,32,32,"protokoll_atpstr_my_2af8b399ea0b8c22c6fc1b13069ad80214f9fa8b"],
["nrm",1,64,64,"protokoll_atpstr_my_edc94794a7d25c504761344c2a8b4afaac43a2d0"],
["std",2,48,48,"protokoll_atpstr_my_88760aa43d575e84b7030b8a6188f74ba5f80dc7"],
["nrm",1,32,128,"protokoll_atpstr_my_1518b94b1627f7a5f7ce55e37817c09306fe714c"],
["nrm",1,48,440,"protokoll_atpstr_my_c13d4886baa4fa2cef7b4f50892895255b04b078"],
["lsi",400,128,128,"protokoll_atpstr_my_2d0c1ae7703dba890de879a4f4409a64f9856908"],
["std",1,48,48,"protokoll_atpstr_my_a473e2c35f909af4ba00d9f1a7a8a454a851ed9c"],
["std",2,128,128,"protokoll_atpstr_my_9f72062a403172caf26fbe878a32becf1403c276"],
["nrm",2,64,64,"protokoll_atpstr_my_c284f1f10aedfccc65cdb7d9b1210ef814cb8f1a"]
);

# TODO: put this in a separate file
# strategy defs
my %sdef =
(
'protokoll_G-E--_008_K18_F1_PI_AE_CS_SP_S0Y' => '  --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(ConstPrio))\' ',
'protokoll_G-E--_045_K18_F1_PI_AE_CS_OS_S0S_sine05' => '  --sine=gf120_gu_RUU_F100_L00100 --oriented-simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(4*Refinedweight(SimulateSOS,1,1,2,1.5,2),3*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(PreferProcessed))\' ',
'protokoll_G-E--_107_C37_F1_PI_AE_Q4_CS_SP_PS_S0Y' => '  --definitional-cnf=24 --split-clauses=4 --split-reuse-defs --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --presat-simplify --prefer-initial-clauses -tKBO6 -warity -c1 -Ginvconjfreq -F1  --delete-bad-limit=1024000000 -WSelectMaxLComplexAvoidPosPred -H\'(4*RelevanceLevelWeight2(SimulateSOS,0,2,1,2,100,100,100,400,1.5,1.5,1),3*ConjectureGeneralSymbolWeight(PreferNonGoals,200,100,200,50,50,1,100,1.5,1.5,1),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(PreferProcessed))\'  ',
'protokoll_X----_auto_sine03' => '  --delete-bad-limit=1024000000 -xAuto -tAuto --sine=gf120_gu_R02_F100_L20000 ',
'protokoll_X----_auto_sine05' => '  --delete-bad-limit=1024000000 -xAuto -tAuto --sine=gf120_gu_RUU_F100_L00100 ',
'protokoll_X----_auto_sine13' => '   --delete-bad-limit=1024000000 -xAuto -tAuto --sine=gf120_h_gu_R02_F100_L20000 ',
'protokoll_X----_sauto_300' => '   --delete-bad-limit=1024000000 --auto ',
'protokoll_my10simple' => '  --definitional-cnf=24 --split-clauses=7 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*FIFOWeight(PreferProcessed),1*FIFOWeight(ConstPrio))\'  ',
'protokoll_my11simple' => '  --definitional-cnf=24 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(1*FIFOWeight(PreferProcessed),2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*Refinedweight(SimulateSOS,1,1,2,1.5,2),2*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\'  ',
'protokoll_my11simple_sine13' => '  --sine=gf120_h_gu_R02_F100_L20000 --definitional-cnf=24 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(1*FIFOWeight(PreferProcessed),2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*Refinedweight(SimulateSOS,1,1,2,1.5,2),2*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\'  ',
'protokoll_my12simple' => '  --definitional-cnf=24 --split-aggressive --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*FIFOWeight(PreferProcessed))\'  ',
'protokoll_my13simple' => '  --definitional-cnf=24 --split-aggressive --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tAuto -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(6*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),8*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*FIFOWeight(PreferProcessed))\'  ',
'protokoll_my14simple' => '  --definitional-cnf=24 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Garity -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(6*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*FIFOWeight(PreferProcessed),1*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*FIFOWeight(ConstPrio))\'  ',
'protokoll_my15simple' => '  --definitional-cnf=24 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectNewComplexAHP -H\'(1*Refinedweight(SimulateSOS,1,1,2,1.5,2),6*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),2*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5))\'  ',
'protokoll_my16simple' => '  --definitional-cnf=24 --split-clauses=4 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(1*FIFOWeight(ConstPrio),1*FIFOWeight(PreferProcessed),1*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\'  ',
'protokoll_my17simple' => '  --definitional-cnf=24 --split-aggressive --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Garity -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(1*FIFOWeight(ConstPrio),1*FIFOWeight(PreferProcessed),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),3*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100,1.5, 1.5, 1),10*Refinedweight(SimulateSOS,1,1,2,1.5,2))\'  ',
'protokoll_my17simple_sine13' => '  --sine=gf120_h_gu_R02_F100_L20000 --definitional-cnf=24 --split-aggressive --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Garity -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(1*FIFOWeight(ConstPrio),1*FIFOWeight(PreferProcessed),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),3*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100,1.5, 1.5, 1),10*Refinedweight(SimulateSOS,1,1,2,1.5,2))\'  ',
'protokoll_my18simple' => '  --definitional-cnf=24  --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectNewComplexAHP -H\'(1*FIFOWeight(ConstPrio),2*FIFOWeight(PreferProcessed),8*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5))\'  ',
'protokoll_my19simple' => '  --definitional-cnf=24 --split-aggressive --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Garity -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),10*Refinedweight(SimulateSOS,1,1,2,1.5,2),2*FIFOWeight(PreferProcessed),8*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(ConstPrio))\' ',
'protokoll_my1KBO_SOS' => '  --definitional-cnf=24  --split-aggressive --split-clauses=4 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(4*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),10*Refinedweight(SimulateSOS,1,1,2,1.5,2),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),1*Clauseweight(PreferProcessed,1,1,1),2*FIFOWeight(PreferProcessed))\'  ',
'protokoll_my1_SOS' => '  --definitional-cnf=24  --split-aggressive --split-clauses=4 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(4*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),10*Refinedweight(SimulateSOS,1,1,2,1.5,2),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),1*Clauseweight(PreferProcessed,1,1,1),2*FIFOWeight(PreferProcessed))\'  ',
'protokoll_my20simple' => '  --definitional-cnf=24  --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO -Garity -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(1*Refinedweight(SimulateSOS,1,1,2,1.5,2),1*FIFOWeight(ConstPrio),10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5))\'  ',
'protokoll_my21simple' => '  --definitional-cnf=24 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(1*FIFOWeight(ConstPrio),2*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*FIFOWeight(PreferProcessed))\'  ',
'protokoll_my22simple' => '  --definitional-cnf=24  --split-clauses=7 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tAuto -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(1*FIFOWeight(ConstPrio),6*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),8*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*FIFOWeight(PreferProcessed),1*Refinedweight(SimulateSOS,1,1,2,1.5,2))\'  ',
'protokoll_my23simple' => '  --definitional-cnf=24  --split-aggressive --split-clauses=4 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Garity -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(1*FIFOWeight(PreferProcessed),10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\'  ',
'protokoll_my24simple' => '  --definitional-cnf=24  --split-aggressive --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Garity -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(1*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),6*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*FIFOWeight(PreferProcessed),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),8*Refinedweight(SimulateSOS,1,1,2,1.5,2))\'  ',
'protokoll_my25simple' => '  --definitional-cnf=24  --split-aggressive --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO -Garity -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(2*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),2*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*FIFOWeight(PreferProcessed),1*FIFOWeight(ConstPrio))\'  ',
'protokoll_my2simple' => ' --definitional-cnf=24  --split-aggressive --split-clauses=4 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(1*Clauseweight(PreferProcessed,1,1,1),2*FIFOWeight(PreferProcessed))\'  ',
'protokoll_my3simple' => ' --definitional-cnf=24 --split-aggressive --split-clauses=4 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Garity -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(1*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*Clauseweight(PreferProcessed,1,1,1),2*FIFOWeight(PreferProcessed))\'  ',
'protokoll_my4simple' => ' --definitional-cnf=24 --split-aggressive --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tAuto -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(6*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(ConstPrio),1*FIFOWeight(PreferProcessed),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1))\'  ',
'protokoll_my5simple' => '  --definitional-cnf=24  --split-aggressive --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO -Garity -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(1*FIFOWeight(ConstPrio),8*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*FIFOWeight(PreferProcessed))\'  ',
'protokoll_my6simple' => '  --definitional-cnf=24  --split-clauses=7 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(1*FIFOWeight(ConstPrio),2*FIFOWeight(PreferProcessed),1*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5))\'  ',
'protokoll_my7simple' => '  --definitional-cnf=24 --split-aggressive --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(1*FIFOWeight(PreferProcessed),1*FIFOWeight(ConstPrio),2*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5))\'  ',
'protokoll_my8simple' => '  --definitional-cnf=24 --split-aggressive --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(1*FIFOWeight(ConstPrio),4*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),2*FIFOWeight(PreferProcessed))\'  ',
'protokoll_my8simple_sine13' => '  --sine=gf120_h_gu_R02_F100_L20000 --definitional-cnf=24 --split-aggressive --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tKBO -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(1*FIFOWeight(ConstPrio),4*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),2*FIFOWeight(PreferProcessed))\'  ',
'protokoll_my9simple' => '  --definitional-cnf=24 --split-aggressive --split-clauses=7 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tAuto -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(6*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*FIFOWeight(ConstPrio),2*Refinedweight(SimulateSOS,1,1,2,1.5,2),2*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),2*FIFOWeight(PreferProcessed),10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),3*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1))\' ',
'protokoll_G-E--_008_B31_F1_PI_AE_S4_CS_SP_S2S' => '  --split-aggressive --split-clauses=4 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectNewComplexAHP -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(ConstPrio))\' ',
'protokoll_G-E--_010_B02_F1_PI_AE_S4_CS_SP_S0Y' => '  --split-aggressive --split-clauses=4 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Garity -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(4*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),3*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(PreferProcessed))\' ',
'protokoll_G-E--_045_B31_F1_PI_AE_S4_CS_SP_S0Y' => '  --split-aggressive --split-clauses=4 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreqconstmin -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(4*Refinedweight(SimulateSOS,1,1,2,1.5,2),3*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(PreferProcessed))\' ',
'protokoll_G-E--_024_B07_F1_PI_AE_Q4_CS_SP_S0Y' => '  --split-reuse-defs --split-clauses=4 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(4*ConjectureGeneralSymbolWeight(SimulateSOS,100,100,100,50,50,50,50,1.5,1.5,1),3*ConjectureGeneralSymbolWeight(PreferNonGoals,100,100,100,50,50,1000,100,1.5,1.5,1),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(PreferProcessed))\' ',
'protokoll_G-E--_045_K18_F1_PI_AE_CS_OS_S0S' => '  --oriented-simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectComplexG -H\'(4*Refinedweight(SimulateSOS,1,1,2,1.5,2),3*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(PreferProcessed))\' ',
'protokoll_G-E--_107_C37_F1_PI_AE_Q4_CS_SP_PS_S0Y_sine13' => '  --sine=gf120_h_gu_R02_F100_L20000 --split-clauses=4 --split-reuse-defs --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --presat-simplify --prefer-initial-clauses -tKBO6 -warity -c1 -Ginvconjfreq -F1 -s --delete-bad-limit=1024000000 -WSelectMaxLComplexAvoidPosPred -H\'(4*RelevanceLevelWeight2(SimulateSOS,0,2,1,2,100,100,100,400,1.5,1.5,1),3*ConjectureGeneralSymbolWeight(PreferNonGoals,200,100,200,50,50,1,100,1.5,1.5,1),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(PreferProcessed))\' ', 
'protokoll_G-E--_052_K18_F1_PI_AE_Q4_CS_SP_S0Y' => '  --split-reuse-defs --split-clauses=4 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -winvfreqrank -c1 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectMaxLComplexAvoidPosPred -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.05, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(SimulateSOS))\' ',
'protokoll_G-E--_092_C01_F1_PI_AE_Q4_CS_SP_PS_S0Y' => '  --definitional-cnf=24 --tstp-in --presat-simplify --split-clauses=4 --split-reuse-defs --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 -s --delete-bad-limit=1024000000 -WSelectMaxLComplexAvoidPosPred -tKBO6 -H\'(4*RelevanceLevelWeight2(SimulateSOS,1,2,0,2,100,100,100,400,1.5,1.5,1),3*ConjectureGeneralSymbolWeight(PreferNonGoals,200,100,200,50,50,1,100,1.5,1.5,1),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(PreferProcessed))\' ',
'protokoll_G-E--_008_C18_F1_PI_AE_Q4_CS_SP_PS_S0Y' => '  --definitional-cnf=24 --split-reuse-defs --split-clauses=4 --tstp-in --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er  --presat-simplify --prefer-initial-clauses -tKBO6 -winvfreqrank -c1 -Ginvfreq -F1 -s --delete-bad-limit=1024000000 -WSelectMaxLComplexAvoidPosPred -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(ConstPrio))\' ',
'protokoll_G-E--_008_B07_F1_PI_AE_Q4_CS_SP_S2S' => '  --split-reuse-defs --split-clauses=4 --simul-paramod --forward-context-sr --destructive-er-aggressive --destructive-er --prefer-initial-clauses -tLPO4 -Ginvfreq -F1 --delete-bad-limit=150000000 -WSelectNewComplexAHP -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(ConstPrio))\' ',


# the tstf6_40_128 prots
'protokoll_atpstr_my_05c900b7acd7e0314c15fce53bb9e79cf904cd89' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 1.5,, 03, 40,1.0)\' --forward-context-sr -winvfreqrank -c1 -Ginvfreq -WSelectNewComplexAHP --simul-paramod --split-aggressive --split-clauses=4 -tLPO4 -H\'(8*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),6*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),4*Clauseweight(ConstPrio,3,1,1),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(PreferProcessed),2*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),4*Refinedweight(SimulateSOS,1,1,2,1.5,2))\'   ' ,
'protokoll_atpstr_my_0b08a1d1a32ffc279e90769114bdfda18e672e1c' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 1.1,, 03, 40,1.0)\' -winvfreqrank -c1 -Ginvfreq -WSelectMaxLComplexAvoidPosPred --simul-paramod --split-aggressive --split-reuse-defs -tAuto -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),4*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),12*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),7*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*FIFOWeight(ConstPrio),2*FIFOWeight(PreferProcessed))\'  ' ,
'protokoll_atpstr_my_37be21ea059a2fcb865621e373a97f33a9d07b12' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 2.0,, 02, 100,1.0)\' --forward-context-sr -Ginvfreqconstmin -WSelectComplexG --simul-paramod --split-clauses=7 --split-reuse-defs -tKBO -H\'(4*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(ConstPrio),1*FIFOWeight(PreferProcessed))\'  ' ,
'protokoll_atpstr_my_3e6c84c618b85cc326775b240e7b2b07e3a2dde9' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 --forward-context-sr -Ginvfreqconstmin -WSelectNewComplexAHP --simul-paramod --split-aggressive --split-clauses=4 -tAuto -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),3*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*Clauseweight(ConstPrio,3,1,1),1*FIFOWeight(ConstPrio))\'  ' ,
'protokoll_atpstr_my_4e6e6157a8ac18b9bae11142d40377c9660db06b' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 6.0,, 02, 100,1.0)\' --forward-context-sr -winvfreqrank -c1 -Ginvfreq -WSelectMaxLComplexAvoidPosPred --simul-paramod -tLPO4 -H\'(10*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),2*Clauseweight(ConstPrio,3,1,1),2*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(ConstPrio),2*FIFOWeight(PreferProcessed),10*Refinedweight(PreferGroundGoals,2,1,2,1.0,1),2*Refinedweight(SimulateSOS,1,1,2,1.5,2))\'  ' ,
'protokoll_atpstr_my_5fce846ef89413a220d0951fb615d42ded72b119' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 --forward-context-sr -Garity -WSelectMaxLComplexAvoidPosPred --simul-paramod --split-clauses=4 --split-reuse-defs -tLPO4 -H\'(8*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),3*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*Clauseweight(ByCreationDate,2,1,0.8),1*Clauseweight(ConstPrio,3,1,1),1*FIFOWeight(PreferProcessed),8*Refinedweight(PreferGroundGoals,2,1,2,1.0,1),1*Refinedweight(SimulateSOS,1,1,2,1.5,2))\' ' ,
'protokoll_atpstr_my_7b674c1081cd73ca6ce34d02596e6f6fd903ac6c' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 5.0,, 02, 80,1.0)\' -Garity -WSelectNewComplexAHP --simul-paramod -tLPO4 -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),2*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),7*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ConstPrio,3,1,1),2*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(PreferProcessed),3*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),2*Refinedweight(PreferGroundGoals,2,1,2,1.0,1),4*Refinedweight(SimulateSOS,1,1,2,1.5,2))\'  ' ,
'protokoll_atpstr_my_92168ebc2ef464a6f2d6a311a4fa90219fd0aa91' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 6.0,, 02, 20000,1.0)\' --forward-context-sr -Garity -WSelectNewComplexAHP --simul-paramod --split-aggressive --split-reuse-defs -tAuto -H\'(6*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),12*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),6*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),4*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),8*Refinedweight(PreferGroundGoals,2,1,2,1.0,1),4*Refinedweight(SimulateSOS,1,1,2,1.5,2))\'  ' ,
'protokoll_atpstr_my_a175515211bb22b22434eae9bbbfab623676a2ba' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 --forward-context-sr -winvfreqrank -c1 -Ginvfreq -WSelectComplexG --simul-paramod --split-clauses=4 --split-reuse-defs -tLPO4 -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*FIFOWeight(PreferProcessed),2*Refinedweight(PreferGroundGoals,2,1,2,1.0,1))\'  ' ,
'protokoll_atpstr_my_a473e2c35f909af4ba00d9f1a7a8a454a851ed9c' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 1.4,, , 20,1.0)\' -Ginvfreqconstmin -WSelectMaxLComplexAvoidPosPred --simul-paramod --split-aggressive --split-clauses=4 -tLPO4 -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*FIFOWeight(PreferProcessed))\'  ' ,
'protokoll_atpstr_my_a74b37f2d8b7e35be554fc999f671188cf40f113' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 6.0,, 01, 80,1.0)\' -Ginvfreqconstmin -WSelectComplexG --simul-paramod --split-clauses=4 --split-reuse-defs -tLPO4 -H\'(6*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),3*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),6*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),2*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(ConstPrio),2*FIFOWeight(PreferProcessed),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\'  ' ,
'protokoll_atpstr_my_c284f1f10aedfccc65cdb7d9b1210ef814cb8f1a' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 5.0,, 02, 60,1.0)\' --forward-context-sr -Garity -WSelectComplexG --simul-paramod --split-clauses=4 --split-reuse-defs -tLPO4 -H\'(2*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*FIFOWeight(ConstPrio),1*FIFOWeight(PreferProcessed),1*Refinedweight(PreferGroundGoals,2,1,2,1.0,1))\'  ' ,
'protokoll_atpstr_my_e4d2b8713a71da3a6bc64790217310975ccdde24' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 1.1,, 01, 20000,1.0)\' -winvfreqrank -c1 -Ginvfreq -WSelectComplexG --simul-paramod --split-clauses=7 --split-reuse-defs -tLPO4 -H\'(1*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),7*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*FIFOWeight(PreferProcessed),2*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\' ' ,
'protokoll_atpstr_my_e8ac4ce30401bd9e99200725cfa03816a32e3aa4' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 5.0,, 01, 20000,1.0)\' --forward-context-sr -Ginvfreqconstmin -WSelectComplexG --simul-paramod --split-aggressive -tLPO4 -H\'(6*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),12*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),4*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(PreferProcessed,1,1,1),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\' ', 

# m10u2_184
'protokoll_atpstr_my_1518b94b1627f7a5f7ce55e37817c09306fe714c' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 1.2,, 02, 40,1.0)\' -winvfreqrank -c1 -Ginvfreq -WSelectMaxLComplexAvoidPosPred --simul-paramod -tAuto -H\'(1*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),8*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*Clauseweight(ByCreationDate,2,1,0.8),2*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(ConstPrio),1*FIFOWeight(PreferProcessed),2*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\'  ', 
'protokoll_atpstr_my_2eeaa79326ed674ea9ebfc3531c32ba1feec013b' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 --forward-context-sr -Garity -WSelectComplexG --simul-paramod -tAuto -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*FIFOWeight(ConstPrio),1*FIFOWeight(PreferProcessed))\'  ', 
'protokoll_atpstr_my_304d2e324da665c057353a60ddd91c0712280c88' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 1.1,, 02, 60,1.0)\' --forward-context-sr -Garity -WSelectMaxLComplexAvoidPosPred --simul-paramod --split-clauses=4 -tLPO4 -H\'(6*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(ConstPrio),2*FIFOWeight(PreferProcessed),4*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\'  ', 
'protokoll_atpstr_my_69856783cec8fab1acccfe08bb382ad42c8475df' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 6.0,, , 100,1.0)\' -Garity -WSelectComplexG --simul-paramod --split-clauses=7 -tKBO -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),7*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),2*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),2*Refinedweight(PreferGroundGoals,2,1,2,1.0,1))\'  ', 
'protokoll_atpstr_my_88760aa43d575e84b7030b8a6188f74ba5f80dc7' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 2.0,, 02, 100,1.0)\' --forward-context-sr -Garity -WSelectComplexG --simul-paramod --split-clauses=7 -tKBO -H\'(8*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),3*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(ConstPrio),2*FIFOWeight(PreferProcessed),3*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\'  ', 
'protokoll_atpstr_my_8fb389ef013a89e03c1aa87be52b2f151b1819cc' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 1.1,, 04, 80,1.0)\' -Garity -WSelectNewComplexAHP --simul-paramod --split-aggressive --split-clauses=4 --split-reuse-defs -tAuto -H\'(6*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),2*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),2*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),2*FIFOWeight(PreferProcessed),1*Refinedweight(PreferGroundGoals,2,1,2,1.0,1))\'  ', 
'protokoll_atpstr_my_a3154f3180cc47331f1b05c36960c32e4805a7c5' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 6.0,, 01, 20000,1.0)\' --forward-context-sr -Garity -WSelectComplexG --simul-paramod --split-clauses=4 -tLPO4 -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),3*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*Clauseweight(PreferProcessed,1,1,1),1*Refinedweight(PreferGroundGoals,2,1,2,1.0,1))\'  ', 
'protokoll_atpstr_my_a4a4da5778ba9bebf9bc5e616786c7ad501b1af5' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 1.1,, 03, 20,1.0)\' --forward-context-sr -winvfreqrank -c1 -Ginvfreq -WSelectMaxLComplexAvoidPosPred --simul-paramod --split-aggressive --split-clauses=4 --split-reuse-defs -tLPO4 -H\'(1*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*Clauseweight(ByCreationDate,2,1,0.8),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(ConstPrio),2*FIFOWeight(PreferProcessed),3*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\'  ', 
'protokoll_atpstr_my_cfee9ff42189552c6557cda7d36f20820c827219' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 1.5,, 04, 100,1.0)\' --forward-context-sr -Garity -WSelectMaxLComplexAvoidPosPred --simul-paramod --split-clauses=4 -tLPO4 -H\'(6*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),6*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),4*Clauseweight(ConstPrio,3,1,1),1*Clauseweight(PreferProcessed,1,1,1),2*FIFOWeight(PreferProcessed),2*Refinedweight(PreferGroundGoals,2,1,2,1.0,1),2*Refinedweight(SimulateSOS,1,1,2,1.5,2))\'  ', 
'protokoll_atpstr_my_e3b5200232138aedc93b8882335da60ccd317d87' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 1.2,, 01, 80,1.0)\' --forward-context-sr -Ginvfreqconstmin -WSelectComplexG --simul-paramod --split-clauses=7 --split-reuse-defs -tLPO4 -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*Clauseweight(PreferProcessed,1,1,1))\'  ', 
'protokoll_atpstr_my_e6869afe09f22abfbe1163ee95524cfdbfe77603' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 2.0,, 04, 40,1.0)\' --forward-context-sr -Garity -WSelectMaxLComplexAvoidPosPred --simul-paramod --split-clauses=4 -tLPO4 -H\'(2*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*Clauseweight(ConstPrio,3,1,1),2*FIFOWeight(PreferProcessed),10*Refinedweight(PreferGroundGoals,2,1,2,1.0,1),1*Refinedweight(SimulateSOS,1,1,2,1.5,2))\'  ', 
'protokoll_atpstr_my_e6ff24ca1a5013a612ccffc94da0b282477718de' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 1.5,, 02, 100,1.0)\' --forward-context-sr -Ginvfreqconstmin -WSelectComplexG --simul-paramod -tKBO -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(ConstPrio))\'  ', 
'protokoll_atpstr_my_eba37f91665fc364eeb63558058658ee9a149d9a' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 1.1,, 02, 60,1.0)\' --forward-context-sr -Garity -WSelectNewComplexAHP --simul-paramod --split-clauses=4 --split-reuse-defs -tLPO4 -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),6*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),10*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),2*Clauseweight(ConstPrio,3,1,1),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(PreferProcessed),3*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),8*Refinedweight(PreferGroundGoals,2,1,2,1.0,1))\'  ', 
'protokoll_atpstr_my_fc3fb6907f504dffe1a6181663296b37fe358480' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 -Ginvfreqconstmin -WSelectMaxLComplexAvoidPosPred --simul-paramod --split-clauses=4 --split-reuse-defs -tLPO4 -H\'(8*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),7*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*Clauseweight(PreferProcessed,1,1,1),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5))\' ',

# new_mzt_small
'protokoll_atpstr_my_2af8b399ea0b8c22c6fc1b13069ad80214f9fa8b' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 5.0,, 6, 80,1.0)\' -Ginvfreqconstmin -WSelectComplexG --simul-paramod --split-reuse-defs -tKBO -H\'(8*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),4*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),2*FIFOWeight(PreferProcessed),10*Refinedweight(SimulateSOS,1,1,2,1.5,2))\' ',
'protokoll_atpstr_my_2d0c1ae7703dba890de879a4f4409a64f9856908' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 1.5,, 2, 60,1.0)\' --forward-context-sr -Garity -WSelectMaxLComplexAvoidPosPred --oriented-simul-paramod --split-aggressive --split-reuse-defs -tLPO4 -H\'(1*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),4*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),8*Clauseweight(ConstPrio,3,1,1),2*Clauseweight(PreferProcessed,1,1,1),2*FIFOWeight(PreferProcessed),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),10*Refinedweight(PreferGroundGoals,2,1,2,1.0,1),4*Refinedweight(SimulateSOS,1,1,2,1.5,2))\' ',
'protokoll_atpstr_my_40306ce1a432dd48c918ac611d77fc5069b2fbc7' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 --forward-context-sr -Garity -WSelectComplexG --simul-paramod -tKBO -H\'(2*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),3*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),10*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),4*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*FIFOWeight(ConstPrio),4*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),2*Refinedweight(SimulateSOS,1,1,2,1.5,2))\' ',
'protokoll_atpstr_my_43029cedefea4858aae9c4ebd6be482056ce22f4' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 --forward-context-sr -Ginvfreqconstmin -WSelectComplexG --simul-paramod -tKBO -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),1*FIFOWeight(PreferProcessed),1*Refinedweight(SimulateSOS,1,1,2,1.5,2))\' ',
'protokoll_atpstr_my_9cb7c8ca63fd56afb053ade56353a3b00eee7e6a' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 1.2,, 4, 100,1.0)\' --forward-context-sr -winvfreqrank -c1 -Ginvfreq -WSelectMaxLComplexAvoidPosPred --simul-paramod --split-clauses=4 --split-reuse-defs -tLPO4 -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(ConstPrio),2*FIFOWeight(PreferProcessed))\' ',
'protokoll_atpstr_my_9f72062a403172caf26fbe878a32becf1403c276' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 2.0,, 3, 20,1.0)\' -Garity -WSelectComplexG --simul-paramod --split-clauses=7 --split-reuse-defs -tKBO -H\'(4*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),6*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),3*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),10*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*FIFOWeight(ConstPrio),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),10*Refinedweight(SimulateSOS,1,1,2,1.5,2))\' ',
'protokoll_atpstr_my_9fde028f05afb32f97bced19843d73b32d923682' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 --forward-context-sr -Ginvfreqconstmin -WSelectComplexG --oriented-simul-paramod --split-aggressive -tKBO -H\'(1*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),3*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),4*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(ConstPrio),2*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),1*Refinedweight(PreferGroundGoals,2,1,2,1.0,1),2*Refinedweight(SimulateSOS,1,1,2,1.5,2))\' ',
'protokoll_atpstr_my_c0d9db6a7b7a90437bd07739f25aa91c0ffc1607' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 --forward-context-sr -Ginvfreqconstmin -WSelectComplexG --simul-paramod --split-clauses=4 -tKBO -H\'(10*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*FIFOWeight(PreferProcessed),1*Refinedweight(PreferGroundGoals,2,1,2,1.0,1))\' ',
'protokoll_atpstr_my_c13d4886baa4fa2cef7b4f50892895255b04b078' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, , 2.0,, 1, 80,1.0)\' --forward-context-sr -Garity -WSelectMaxLComplexAvoidPosPred --simul-paramod -tKBO -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),4*ConjectureRelativeSymbolWeight(SimulateSOS,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),4*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(ConstPrio),1*Refinedweight(PreferNonGoals,1,1,2,1.5,1.5),1*Refinedweight(SimulateSOS,1,1,2,1.5,2))\' ',
'protokoll_atpstr_my_d60b37aca40b6e560cee4bde2efc36c05a24873f' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 -Garity -WSelectComplexG --simul-paramod -tLPO4 -H\'(1*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),2*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),2*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*FIFOWeight(ConstPrio),1*FIFOWeight(PreferProcessed))\' ',
'protokoll_atpstr_my_edc94794a7d25c504761344c2a8b4afaac43a2d0' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000  --sine=\'GSinE(CountFormulas, hypos, 5.0,, , 100,1.0)\' --forward-context-sr -Ginvfreqconstmin -WSelectMaxLComplexAvoidPosPred --simul-paramod --split-clauses=4 --split-reuse-defs -tKBO -H\'(6*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*ConjectureRelativeSymbolWeight(PreferNonGoals,0.5, 100, 100, 100, 100, 1.5, 1.5, 1),2*ConjectureSymbolWeight(ConstPrio,10,10,5,5,5,1.5,1.5,1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*FIFOWeight(ConstPrio),1*FIFOWeight(PreferProcessed),1*Refinedweight(PreferGroundGoals,2,1,2,1.0,1))\' ',
'protokoll_atpstr_my_f67d73f57ffeda22ddd93400237cd848911520e5' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 -Garity -WSelectComplexG --simul-paramod --split-aggressive --split-clauses=4 -tLPO4 -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(PreferProcessed))\' ',
'protokoll_atpstr_my_f9ecf400d7420b0148b2ef7cf4b1498512cf83fd' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 --forward-context-sr -winvfreqrank -c1 -Ginvfreq -WSelectMaxLComplexAvoidPosPred --simul-paramod -tLPO4 -H\'(6*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*Clauseweight(ByCreationDate,2,1,0.8),1*Clauseweight(PreferProcessed,1,1,1),1*FIFOWeight(ConstPrio),2*FIFOWeight(PreferProcessed),2*Refinedweight(PreferGroundGoals,2,1,2,1.0,1))\' ',
'protokoll_atpstr_my_fe548d15a6fc730fd350de634ad9d912ae198efd' => '  --definitional-cnf=24 --destructive-er-aggressive --destructive-er --prefer-initial-clauses -F1 --delete-bad-limit=150000000 --simul-paramod --forward-context-sr -winvfreqrank -c1 -Ginvfreq -WSelectMaxLComplexAvoidPosPred -H\'(10*ConjectureRelativeSymbolWeight(ConstPrio,0.1, 100, 100, 100, 100, 1.5, 1.5, 1.5),1*FIFOWeight(ConstPrio))\' '
);



my $gparallel = 4; # the parallelization (nr of cores) - should be a parameter
my $greflimit = 800;  # how many hints we want from the ranker before we do slicing (just for speed up)
my $gdolsi = 1; # do the lsi training/predictions or not


AITP_Data::PrepareKNNTrain($gfilestem, 0, $gminrefs, $grefsyms, $greftrmstd, $greftrmnrm, \%gstdnr, \%gnrmnr);

my $time1 = time();
print "\nTime spent in data preparation:", $time1 - $gstarttime, "\n";

my ($glsiranking400,$glsioverlap400,$glsinames400); 
my ($glsiranking1000,$glsioverlap1000,$glsinames1000);

if($gdolsi > 0)
{
    ($glsiranking400,$glsioverlap400,$glsinames400) = AITP_Data::RunLSI($gfilestem,0,512,400,$grefsyms);
#    ($glsiranking1000,$glsioverlap1000,$glsinames1000) = AITP_Data::RunLSI($gfilestem,0,512,1000,$grefsyms);

    print "\nTime spent in LSI:", time() - $time1 , "\n";
}

print "\nTime spent in all preparation:", time() - $gstarttime, "\n";

# this is how we will run knn:
# ~/gr/MPTP2/MaLARea/script/knn.pl -w1 -L10 -M5 -t 001  02symst_notrivsyms  00c8k 40:20:10:5:4 1 0 


my $iter = 0;



# TODO: now just a stub, should be doing pseudo-minimization
sub Minimize
{
    my ($conj1,$nr1,$refs1,$strategy,$problem_limit,$ref2fla) = @_;
    return ($conj1,$nr1,$refs1); # if($nr1 < 4);

# write the file
# run atp
# extract the proof
}



# strat looks like:
# ["nrm",1,48,160,"protokoll_atpstr_my_a175515211bb22b22434eae9bbbfab623676a2ba"]
sub RunStrategy
{
    my ($strat,$conj,$tl,$solutionfile) = @_;

    my ($kind,$weighting,$k,$s,$estrat) = @$strat;

    #my @bla = ($kind,$weighting,$k,$s,$estrat);
    #foreach my $ff (0..$#bla) { die "Undefined $ff" unless(defined($bla[$ff])) }

    my $file = "$MTMP/$conj/$conj.prob.$kind.w$weighting.k$k.s$s";
    die "Cannot read problem file $file" unless(-r $file);

    #print "Command: ulimit -t $tl; $MBIN/eprover $sdef{$estrat} --tstp-format -R -s --cpu-limit=$tl $file 2>$file.err.$estrat | grep \"\\(User\\|SZS status\\)\" | tee $file.out.$estrat\n";

    die "Unknown strategy: $estrat\n$sdef::\n" unless(exists($sdef{$estrat}));

    dprint "Running ", join('.',@$strat), "for $tl s:\n";

    my $eparams = $sdef{$estrat};

    my @lines = `ulimit -t $tl; $MBIN/eprover  $eparams  --tstp-format -R -s --cpu-limit=$tl $file 2>$file.err.$estrat | grep "\\(User\\|SZS status\\)" | tee $file.out.$estrat`;

    foreach $_ (@lines)
    {
	if(m/.*SZS status[ :]*(Theorem)/)
	{
	    my $tl1 = 10+$tl;
	    my @plines = `ulimit -t $tl1; $MBIN/eprover $sdef{$estrat} --cpu-limit=$tl1 --memory-limit=Auto --tstp-in -l4 -o- --pcl-terms-compressed --pcl-compact $file |$MBIN/epclextract --tstp-out -f -C --competition-framing`;

	    my @status = grep { /.*SZS status[ :]*(Theorem)/ } @plines;
	    open(F,">$file.$estrat.out1"); 
	    if(scalar(@status)>0)
	    {
		mywarn "Proof found by slice ", join('.',@$strat), "\n"; 
		print F @plines;
		close(F);
		open(G,">$solutionfile") or die " Cannot open solution file: $solutionfile";
		flock(G, 2); ## exclusive lock, will wait until all locks are removed
		print G "# MaLARea strategy is $kind.w$weighting.k$k.s$s $estrat\n";
		print G @plines;
		flock(G, 8);
		close(G);
		dprint "Done:$strat\n";		
		exit(0);
	    }
	    else
	    {
		print F "# SZS status Theorem\n"; 
		close(F); # only return; do not exit, some other slice in this child could still assemble a proof
		return(0);
	    }
	}
    }
    dprint "Done:$strat\n";
    return;
}




# This is causes the child to exit
sub RunStrategiesSerial
{
    my ($strats,$conj,$problem_limit,$solutionfile) = @_;

    my $tl = max( 1, int( $problem_limit/(1+(scalar @$strats)) ));

    my $slack = $problem_limit - $tl*(1+(scalar @$strats));

    # if success, the child will exit in RunStrategy
    foreach my $strat (0 .. scalar(@$strats)-1)
    {
	my $tl1 = $tl;
	if($slack > 1)
	{
	    $slack--;
	    $tl1++;
	}
	RunStrategy($strats->[$strat],$conj,$tl1,$solutionfile);
    }    
    dprint "Done: RunStrategiesSerial\n";
    exit(0);
}


# run the strategies on the problem; return the status and the successful strategy (if any)
# 
sub RunStrategiesParallel
{
    my ($strats,$conj,$problem_limit,$parallel,$solutionfile) = @_;

    my $chunk_tlimit = $problem_limit; # no dividing, here we gain on parallelization

    my @stratchunks = (); # equal-sized chunks, make $parallel number of them 

    foreach my $i (0 .. $parallel-1) { $stratchunks[$i] = []; }

    # the strats go into the chunks according to their modulo $parallel
    foreach my $j (0 .. scalar(@$strats)-1)
    {
	my $mod = $j % $parallel;
	push( @{$stratchunks[$mod]}, $strats->[$j]);
    }

    my $status = szs_UNKNOWN ;

    # the parent ends the chunks by sending them $SIG{HUP}
    # the chunks speak to the parent by creating 

    my @childs = ();
    foreach my $chunk (@stratchunks)
    {

	my $pid = fork();
	if ($pid) 
	{
	    # parent
	    push(@childs, $pid);
	} 
	elsif ($pid == 0) 
	{
	    # child, if successful, creates the proof
	    $SIG{USR1} = \&childstopped;
	    RunStrategiesSerial($chunk,$conj,$chunk_tlimit,$solutionfile);
	    exit(0);
	} 
	else 
	{
	    die "couldn’t fork: $!\n";
	}
    }

    dprint "Parent:@childs\n";

    my $resultstrat = '';

    # while children exist, we update each second the list of
    # children, killing them all upon success
  LOOP1: while(scalar(@childs) > 0)
    {
	sleep 1;
	dprint "Parent:@childs\n";

	my @reaped = ();
	my %reapedh = ();
	while ((my $kid = waitpid(-1,WNOHANG)) > 0 )
	{
	    push(@reaped, $kid);
	    $reapedh{$kid} = ();
	}

	# If the prooffile is readable and unlocked, we wait
	# to get an exclusive lock and then kill all the children.
	# As soon as we get the lock, we know that the file is
	# written and no child will be able to change it
	# before we kill it. After they are all killed and reaped, we unlock.
	if(-e $solutionfile)
	{
	    open(MYFILE, $solutionfile) or die "Error in locking";
	    flock(MYFILE, 2); ## exclusive lock, will wait until all locks are removed
	    kill 10, @childs; # SIGUSR1
	    dprint "Waiting:\n";
	    foreach (@childs) { waitpid($_, 0);}
	    dprint "Waited:\n";
	    my $strline = <MYFILE>;
	    if($strline =~ m/^# MaLARea strategy is\s+([^.]+)\.w(\d+)\.k(\d+)\.s(\d+)\s+(.*)/)
	    {
		$resultstrat = [$1,$2,$3,$4,$5];
	    }
	    else { mywarn "Bad strategy line in $solutionfile: $strline\n"; }
	    #flock(MYFILE, 8);
	    close(MYFILE);   # unlocks
	    $status = szs_THEOREM ;
	    @childs = ();
	    last LOOP1;
	}
	else
	{
	    my @newchilds = ();
	    foreach my $c (@childs)
	    {
		push(@newchilds,$c) unless(exists($reapedh{$c}));
	    }
	    @childs = @newchilds;
	}
    }

    # TODO: the strategy should write its name into the prooffile - needed for minimization
    return ($status,$resultstrat);
}


# solve the problem with $problem_limit, getting the features from unknown flas first
sub Solve
{
    my ($prob,$problem_limit,$solutionfile,$forgetlimit,
	$iter,$ref2fla,$allallowed,$parallel) = @_;

    my $starttime = time();

    my @lines = `$MBIN/tptp4X -f tptp:short  -u machine -c $prob | $MBIN/CompressInsaneNames.pl `;
    return szs_GAVEUP if($#lines > $forgetlimit);  ## forget about this one
 
    my %getfeatures = (); # we need features from these
    my %allowed = ();  # these are the refs allowed for $prob
    my $conj = '';

    @allowed{@$allallowed} = ();
    foreach $_ (@lines)
    {

	if(m/^ *fof\( *([^, ]+) *, *([^, ]+) *,(.*)/)
	{
	    if(!exists($grefsyms->{$1}))
	    {
		$getfeatures{$1} = $_ ;
		mywarn "Features missing for $1\n";
	    }
	    if($2 eq 'conjecture')
	    {
		$conj = $1 
	    }
	    else { $allowed{$1} = (); }
	}
	elsif(m/^\s*include[(]\s*[']([^']+)[']\s*[)]\.\s*$/)
	{
	    my $i = $1;
	    my ($volume,$directories,$file) = File::Spec->splitpath( $i );
	    die "Include file was not known during training: $i" 
		unless(exists($gincludes->{$file}));
	    my @refs0 = keys %{$gincludes->{$file}};
	    @allowed{@refs0} = ();	    
	}
    }

    if($conj eq '') 
    { 
	mywarn "No conjecture in $prob, giving up\n";
	return szs_GAVEUP;
    }

    `mkdir $MTMP/$conj`;

    AITP_Data::PrepareKNNTest("$MTMP/$conj/$conj.test", $iter, $conj, $grefsyms,
			      $greftrmstd, $greftrmnrm, \%gstdnr, \%gnrmnr);

    # copy the full problem
    `cp $prob $MTMP/$conj/$conj.prob.ful.w0.k0.s0`;

    # make the lsi files

    if($gdolsi > 0)
    {
	my @manyknn = (8,16,32,48,64,128,256,512);

	AITP_Data::MakeLSIPredictions($conj,$gfilestem,400,$iter,\%allowed,$ref2fla,\@manyknn,
				      $gminrefs,$glsiranking400,$glsioverlap400,$glsinames400);
#	AITP_Data::MakeLSIPredictions($conj,$gfilestem,1000,$iter,\%allowed,$ref2fla,\@manyknn,
#				      $gminrefs,$glsiranking1000,$glsioverlap1000,$glsinames1000);
    }

    my @childs = ();
    foreach my $weighting (1,2)
    {
	foreach my $kind ('nrm','std')
	{
	    my $pid = fork();
	    if ($pid) 
	    {
		# parent
		push(@childs, $pid);
	    } 
	    elsif ($pid == 0) 
	    {
		# child
		AITP_Data::MakeKNNPredictions($conj,$gfilestem,$weighting,$greflimit,$kind,$iter,\%allowed,$ref2fla);
		exit(0);
	    } 
	    else 
	    {
		die "couldn’t fork: $!\n";
	    }
	}
    }

    foreach (@childs) { waitpid($_, 0);}

    my $remaining_secs = $problem_limit - (time() - $starttime);

    # run on $MTMP/$conj/$conj.prob.$kind.w$weighting.k$k.s$s
    my ($status,$strategy) = RunStrategiesParallel(\@gLTBstrats,$conj,$remaining_secs,$parallel,$solutionfile);

    print "\nTime used for $prob: ", time() - $starttime, "\n";
    return ($status,$strategy);
}



foreach my $batch (@$gbatches)
{

    my ($execution_order, $output_required, $problem_limit, $overall_limit, 
	$include_files1, $ltbprobnames1, $ltbprobsolutions1) 
	= @$batch;

    my %include_files = %$include_files1;
    my @ltbprobnames = @$ltbprobnames1; 
    my %ltbprobsolutions = %$ltbprobsolutions1;

    # formulas in the batch inclusion files are allowed in each problem
    my %allallowedh = ();
    foreach my $i (sort keys %$include_files1)
    {
	my ($volume,$directories,$file) = File::Spec->splitpath( $i );
	die "Include file was not known during training: $i" 
	    unless(exists($gincludes->{$file}));
	my @refs0 = keys %{$gincludes->{$file}};
	@allallowedh{@refs0} = ();	    
    }

    my @allallowed = sort keys %allallowedh;

    my $remaining_secs = $overall_limit - (time() - $gstarttime);
    foreach my $prob (@ltbprobnames)
    {
	print "\n% SZS status Started for $prob\n";
	my ($status,$strategy) = Solve($prob,$problem_limit,$ltbprobsolutions{$prob},$gforgetlimit,
				       $iter,$gref2fla,\@allallowed,$gparallel);

	print "\n% SZS status $status for $prob\n";
	print "\n% SZS status Ended for $prob\n";
	
	# update if possible
	if($status eq szs_THEOREM)
	{
	    my ($conj1,$nr1,$refs1) = AITP_Data::GetProofSummary($ltbprobsolutions{$prob});
	    if($nr1 != 0)
	    {
		my ($conj2,$nr2,$refs2) = Minimize($conj1,$nr1,$refs1,$strategy,$problem_limit,$gref2fla);

		($conj1,$nr1,$refs1) = ($conj2,$nr2,$refs2) if($nr2 != 0);

		$gminrefs->{$conj1} = $refs1;
		$iter++;
		AITP_Data::PrepareKNNTrain($gfilestem, $iter, $gminrefs, $grefsyms, 
					   $greftrmstd, $greftrmnrm, \%gstdnr, \%gnrmnr);
	    }
	}

	$remaining_secs = $overall_limit - (time() - $gstarttime);
	print "\nTime remaining: $remaining_secs\n";
    }
    $gstarttime = time();
}

exit(0);
