package AITP_Data;

# Now mostly data extraction

use strict;
use Pod::Usage;
use Getopt::Long;
use IPC::Open2;
use File::Spec;

my $MROOT = "/home/mptp/gr/MPTP2/MaLARea";
$MROOT = $ENV{"MLAR_ROOT"} if(exists($ENV{"MLAR_ROOT"}));
my $MBIN = "$MROOT/bin";
my $MSCRIPT = "$MROOT/script";
my $MTMP = "$MROOT/tmp";
my $MTMPAX = "$MROOT/tmp/Axioms";

sub mywarn { print @_; }

my $gfailres = 'zzzfail';

## test: perl -e 'use AITP_Data; ($w,$c,$e)= AITP_Data::GetProofSummary("MZT000+1.MML"); print $w,$c,@$e;'

# ProofSummary from one file or (zzzfail,0,[])
sub GetProofSummary
{
  my ($fname) = @_;
  die "$fname not readable!" unless(-e $fname);
  my @needed_refs = ();
  my $conj;
  my @lines = `$MBIN/tptp4X -c -u machine $fname | sed -e 's/,lemma,/,axiom,/' | $MBIN/CompressInsaneNames.pl`;
  foreach $_ (@lines)
  {
      my ($nm, $status, $rest) = ('','','');
      if(m/^\s*fof\(\s*([^, ]+)\s*,\s*(axiom|conjecture|theorem)\s*,(.*)/)
      {
	  ($nm, $status, $rest) = ($1,$2,$3);
      }
      elsif(m/^\s*fof\(\s*([^, ]+)\s*,\s*negated_(conjecture)\s*,(.*,file\(.*)/)
      {
	  ($nm, $status, $rest) = ($1,$2,$3);
      }
      if(length($nm)>0)
      {	  
	  my $src = '';
	  if($rest =~ m/,\s*file\([^\),]+,\s*([^\)]+)\s*\)/)
	  {
	      $src = $1;
	  }
	  elsif(!($nm =~ m/^[f]?\d+/))
	  {
	      $src = $nm;
	  }
	  else { mywarn "Uknown source of axiom or conjecture: $_"}

	  if($status eq 'axiom')
	  {
	      push(@needed_refs, $src) if($src ne '');
	  }
	  elsif($status =~ m/(conjecture|theorem)/)
	  {
              # ,inference(mizar,[status(thm)],[commutativity_k2_xboole_0,gh])).
	      $conj = $src if($src ne '');
	      if($rest =~ m/,\s*inference\([^,]+,[^,]+,\s*\[([^\]])\s*\]/)
	      {
		  @needed_refs = split(/\, */, $1);
	      }
	  }
      }
  }

  if(defined($conj))
  {
      return ($conj,scalar(@needed_refs),[@needed_refs]);
  }
  else
  {
    mywarn "ProofSummary failed on $fname\n";
    mywarn "No conjecture in $fname\n";
    return ($gfailres,0,[]);
  }
}

# ProofSummary from one file or (zzzfail,0,[])
sub GetProofSummaryOld
{
  my ($fname) = @_;
  die "$fname not readable!" unless(-e $fname);
  my $res = `$MBIN/ProofSummary $fname | grep -v '%' |grep '^proved'`;
  if($res =~ m/^\s*proved\(\s*([^,]+)\s*,\s*\[([^\]]*)\s*\]\)\./)
  {
    my ($conj,$needed_str) = ($1, $2);
    my @needed_refs = split(/\, */, $needed_str);
    return ($conj,scalar(@needed_refs),[@needed_refs]);
  }
  else
  {
    mywarn "ProofSummary failed on $fname\n";
    my $res1 = `grep '^ *fof(.*, *conjecture[ ,]' $fname`;
    if($res1 =~ m/^ *fof\([ ]*([^ ,]*)[ ]*, *conjecture/)
    {
      return ($1,0,[]);
    }
    else
    {
      mywarn "No conjecture in $fname\n";
      return ($gfailres,0,[]);
    }
  }
}

## test: perl -e 'use AITP_Data; ($w,$c,)= AITP_Data::DirProofSummary("/home/mptp/big/tst1/TrainingData.HOL/Solutions"); foreach $k (sort keys %$w) { print $k,":",join(",",@{$w->{$k}}),"\n"}'

## test: perl -e 'use AITP_ProblemIO; ($category, $training_directory, $batches) = AITP_ProblemIO::ReadLTBData("BatchSampleLTBHOL"); print "$category,$training_directory\n"; use AITP_Data; ($w,$c,)= AITP_Data::DirProofSummary("$training_directory/Solutions"); foreach $k (sort keys %$w) { print $k,":",join(",",@{$w->{$k}}),"\n"}'

# assumes that multiple solutions are in a separate directory for each file
sub DirProofSummary
{
  my ($dir) = @_;
  my %minrefs = ();
  my %minrefsnr = ();
  foreach my $i (glob("$dir/*/*"))
  {
    my ($conj,$nr,$refs) = GetProofSummary($i);
    if($conj ne $gfailres)
    {
      if((!exists($minrefsnr{$conj})) ||
	 (0 == $minrefsnr{$conj}) ||
	 ($nr < $minrefsnr{$conj}))
      {
	$minrefsnr{$conj} = $nr;
	$minrefs{$conj} = $refs;
      }
    }
  }
  return (\%minrefs, \%minrefsnr);
}

## test: perl -e 'use AITP_Data; ($w)= AITP_Data::DirIncludeFiles("/home/mptp/big/tst1/TrainingData.HOL/Axioms"); foreach $k (sort keys %$w) { print $k,":",join(",",keys %{$w->{$k}}),"\n"}'

## test: perl -e 'use AITP_ProblemIO; ($category, $training_directory, $batches) = AITP_ProblemIO::ReadLTBData("BatchSampleLTBHOL"); print "$category,$training_directory\n"; use AITP_Data; ($w,$c,)= AITP_Data::DirIncludeFiles("$training_directory/Axioms"); foreach $k (sort keys %$w) { print $k,":",join(",",keys %{$w->{$k}}),"\n"}'

# return a hash of include basenames, each with its included refs
# normalize the files into .tnorm1 files
sub DirIncludeFiles
{
  my ($dir) = @_;
  my %includes = ();
  foreach my $i (glob("$dir/*"))
  {
    my ($volume,$directories,$file) = File::Spec->splitpath( $i );

    $includes{$file} = {};

    my @lines = `$MBIN/tptp4X -f tptp:short  -u machine -c $i | sed -e 's/,lemma,/,axiom,/' | $MBIN/CompressInsaneNames.pl | tee $MTMPAX/$file.tnorm1`;
    foreach $_ (@lines)
    {

      if(m/^ *fof\( *([^, ]+) *, *([^, ]+) *,(.*)/)
      {
	  ${$includes{$file}}{$1} = ();
      }
      else { die "bad line in include file $i: $_"}      
    }
  }
  return (\%includes);
}

my $gdotrmstd = 1;
my $gdotrmnrm = 1;

# these are now irrelevant
my $gsymoffset    = 2000000; # offset at which symbol numbering starts
my $gstdtrmoffset = 4000000; # offset at which standard term numbering starts
my $gnrmtrmoffset = 6000000; # offset at which normalized term numbering starts


# LoadTermTable($filename,$ref2trm_hash,$offset)
#
# Expects a file created by running fofshared, containing list of 
# shared term codes for references. Loads them into $ref2trm_hash,
# shifting the features numbering by $offset.
sub LoadTermTable
{
    my ($filename,$ref2trm_hash,$offset) = @_;

    open(TRMSTD, "$filename") or die "Cannot read $filename file";
    while($_=<TRMSTD>)
    {
	chop; 
	m/^terms\( *([^ ,]+) *, *\[(.*)\] *\)\./ 
	    or die "Bad terms info: $_";
	my ($ref, $trms) = ($1, $2);
	my @trms = split(/, +/, $trms);
	die "Duplicate reference $ref in $_" if exists $$ref2trm_hash{$ref};
	$$ref2trm_hash{$ref} = [];
	my ($sym);
	foreach $sym (@trms)
	{
	    # $sym =~ m/^ *([0-9]+) */ or die "Bad term code $sym in $_";
	    push(@{$$ref2trm_hash{$ref}}, $sym); # $1 + $offset);
	}
    }
    close TRMSTD;
}

# assumes that refsyms and trmnrm and stdtrm exist already, retutns
# (\%grefnr, \%gsymnr, \%gsymarity, \%grefsyms, \@gnrsym, \@gnrref, \%greftrmstd, \%greftrmnrm);
sub CreateTables
{
    my ($filestem) = @_;
    my ($ref,$sym,$trms,@syms,$psyms,$fsyms);

    open(REFSYMS, "$MTMP/$filestem.refsyms") or die "Cannot read refsyms file";
    open(REFNR, ">$MTMP/$filestem.refnr") or die "Cannot write refnr file";
    open(SYMNR, ">$MTMP/$filestem.symnr") or die "Cannot write symnr file";

    my %grefnr = ();
    my %gsymnr = ();
    my %gsymarity = ();
    my %grefsyms = ();
    my @gnrsym = ();
    my @gnrref = ();
    my %greftrmstd = ();
    my %greftrmnrm = ();

    while($_=<REFSYMS>)
    {
	chop; 
	m/^symbols\( *([^ ,]+) *, *\[(.*)\] *, *\[(.*)\] *\)\./ 
	    or die "Bad symbols info: $_";
	($ref, $psyms, $fsyms) = ($1, $2, $3);
	my @psyms = split(/\,/, $psyms);
	my @fsyms = split(/\,/, $fsyms);
	die "Duplicate reference $ref in $_" if exists $grefnr{$ref};
	$grefsyms{$ref} = [];
	push(@gnrref, $ref);
	$grefnr{$ref} = $#gnrref;
	print REFNR "$ref\n";

	## this now also remembers arity and symbol kind in %gsymarity
	foreach $sym (@psyms)
	{
	    $sym =~ m/^ *([^\/]+)[\/]([^\/]+)[\/].*/ or die "Bad symbol $sym in $_";
	    $gsymarity{$1} = [$2, 'p'];
	    push(@{$grefsyms{$ref}}, $1);
	}
	foreach $sym (@fsyms)
	{
	    $sym =~ m/^ *([^\/]+)[\/]([^\/]+)[\/].*/ or die "Bad symbol $sym in $_";
	    $gsymarity{$1} = [$2, 'f'];
	    push(@{$grefsyms{$ref}}, $1);
	}

    }
    close REFNR;

    my $i = 0;
    foreach $sym (keys %gsymarity)
    {
	print SYMNR "$sym\n";
	push(@gnrsym, $sym);
	$gsymnr{$sym} = $gsymoffset + $i++;
    }
    close SYMNR;
    close REFSYMS;

    LoadTermTable("$MTMP/$filestem.trmstd",\%greftrmstd,$gstdtrmoffset) if($gdotrmstd > 0);
    LoadTermTable("$MTMP/$filestem.trmnrm",\%greftrmnrm,$gnrmtrmoffset) if($gdotrmnrm > 0);

    return (\%grefnr, \%gsymnr, \%gsymarity, \%grefsyms, \@gnrsym, \@gnrref, \%greftrmstd, \%greftrmnrm);

}

my $gshgenfeatureprg = 'fofshared.trms';


## test: time perl -e 'use AITP_Data; ($minrefs,$c)= AITP_Data::DirProofSummary("/home/mptp/big/tst1/TrainingData.HOL/Solutions"); ($w)= AITP_Data::DirIncludeFiles("/home/mptp/big/tst1/TrainingData.HOL/Axioms"); AITP_Data::PrepareTables("","bla");'

## test: perl -e 'use AITP_ProblemIO; ($category, $training_directory, $batches) = AITP_ProblemIO::ReadLTBData("BatchSampleLTBHOL"); print "$category,$training_directory\n"; use AITP_Data; ($minrefs,$c)= AITP_Data::DirProofSummary("$training_directory/Solutions"); ($w,$c,)= AITP_Data::DirIncludeFiles("$training_directory/Axioms"); AITP_Data::PrepareTables("","bla");'

# prepare the training data - features and refs, returns the global tables:
#    (\%gref2fla, \%grefnr, \%gsymnr, \%gsymarity, \%grefsyms, \@gnrsym, \@gnrref, \%greftrmstd, \%greftrmnrm);
sub PrepareTables
{
    my ($training_directory,$filestem) = @_;

    `cat $MTMPAX/*.tnorm1 | sort -u > $MTMP/$filestem.allasax`;

    # create the refsyms file
    `cat $MTMP/$filestem.allasax | $MBIN/GetSymbols -- > $MTMP/$filestem.refsyms`;

    # create the trmstd and trmnrm files

    `cat $MTMP/$filestem.allasax | $MBIN/$gshgenfeatureprg - > $MTMP/$filestem.trmstd`;

    my %gref2fla = ();
    my @lines1 = `cat $MTMP/$filestem.allasax`;
    foreach $_ (@lines1)
    {
	if(m/^ *fof\( *([^, ]+) *, *([^, ]+) *,(.*)/)
	{
	    my ($nm,$status,$rest)=($1,$2,$3);
	    if(! (exists $gref2fla{$nm}))
	    {
		$gref2fla{$nm} = $rest . "\n";
	    }
	    else { mywarn "Duplicate formula name: $nm\n"; }
	}
    }

    my $fofsh_pid = open(FOFSH,"|$MBIN/$gshgenfeatureprg - > $MTMP/$filestem.trmnrm");
    foreach my $line (@lines1)
    {
	$line =~ s/([\(, ])[A-Z][a-zA-Z0-9_]*/$1A/g;
	print FOFSH $line;
    }
    close(FOFSH);

#    return (\%grefnr, \%gsymnr, \%gsymarity, \%grefsyms, \@gnrsym, \@gnrref, \%greftrmstd, \%greftrmnrm);
    return (\%gref2fla, CreateTables($filestem));

}

## test: time perl -e 'use AITP_Data; ($minrefs,$c)= AITP_Data::DirProofSummary("/home/mptp/big/tst1/TrainingData.HOL/Solutions"); ($w)= AITP_Data::DirIncludeFiles("/home/mptp/big/tst1/TrainingData.HOL/Axioms"); my ($gref2fla, $grefnr, $gsymnr, $gsymarity, $grefsyms, $gnrsym, $gnrref, $greftrmstd, $greftrmnrm) = AITP_Data::PrepareTables("","bla"); AITP_Data::PrepareKNNTrain("bla", 0, $minrefs, $grefsyms, $greftrmstd, $greftrmnrm); ' 

# prepare the files used by knn and lsi
# in particular, merge the ref/feature info into just one line for each formula
sub PrepareKNNTrain
{
	my ($filestem, $iter, $minrefs, $grefsyms, $greftrmstd, $greftrmnrm, $gstdnr, $gnrmnr) = @_;
	open(ALLFEATSTD,">$MTMP/$filestem.allfeatstd_$iter") or die;
	open(ALLFEATNRM,">$MTMP/$filestem.allfeatnrm_$iter") or die;
	open(ALLFEATLSI,">$MTMP/$filestem.allfeatlsi_$iter") or die;
	open(ALLREFS,">$MTMP/$filestem.allrefs_$iter") or die;
	my $s = scalar(keys %$gstdnr);
	my $n = scalar(keys %$gnrmnr);
	print ALLFEATLSI scalar(keys %$grefsyms), "\n";
	foreach my $k (sort keys %$grefsyms) 
	{
#	    my $syms = join(", ", @{$grefsyms->{$k}});
#	    my $trmstd = join(", ", @{$greftrmstd->{$k}});
#	    my $trmnr = join(", ", @{$greftrmstd->{$k}});

	    my $trmstd = join(", ", map {if(!exists($gstdnr->{$_})) {$gstdnr->{$_}=$s++}; $gstdnr->{$_} } @{$greftrmstd->{$k}});
	    my @trmnrmarr = map {if(!exists($gnrmnr->{$_})) {$gnrmnr->{$_}=$n++}; $gnrmnr->{$_} } @{$greftrmnrm->{$k}};
	    my $trmnrm = join(", ", @trmnrmarr);

	    print ALLFEATSTD ($k,":",join(", ", (@{$grefsyms->{$k}}, $trmstd)),"\n");
	    print ALLFEATNRM ($k,":",join(", ", (@{$grefsyms->{$k}}, $trmnrm)),"\n");
	    print ALLFEATLSI (join(" ", (@{$grefsyms->{$k}}, @trmnrmarr)),"\n");
	}  

	foreach my $k (sort keys %$grefsyms) 
	{
	    my @refs = exists($minrefs->{$k})?  ($k, @{$minrefs->{$k}}) : ($k);
	    print ALLREFS ($k,":",join(" ", @refs),"\n");
	}  

	close(ALLFEATSTD);
	close(ALLFEATNRM);
	close(ALLFEATLSI);
	close(ALLREFS);
}

# TODO: evaluate which topicsnr and features are good

# Produce the LSI rankings and overlaps.
# This is expensive, run only once or rarely.
sub RunLSI
{
    my ($filestem,$iter,$reflimit,$topicsnr,$grefsyms) = @_;
    my $features =   "$MTMP/$filestem.allfeatlsi_$iter";
    my @lsinames = sort keys %$grefsyms;
    my @names = @lsinames;

    my %lsiranking = ();
    my %lsioverlap = ();

    my $suffix = $topicsnr . '_' . $iter;

    open(LSI, "$MSCRIPT/MkLSIRanks.py $features $topicsnr $reflimit | tee $MTMP/$filestem.allreslsi$suffix|") 
	or die("Cannot start MkLSIRanks.py: $iter"); 

    # [(1, 0.99999982), (1813, 0.7591055), (3249, 0.71614057)]
    while($_=<LSI>)
    {
	die "LSI not in sync with refs" if(scalar(@names)==0);
	my $conj = shift @names;
	m/^\[\((.*)\)\]/ or die "Bad LSI line: $_";
	my $vecs = $1;
	my @vec = split(/\)\, *\(/, $vecs);
	my @ranks = ();
	my @overlaps = ();
	foreach my $r (@vec)
	{
	    $r =~ m/^(\d+), *(\S+)/ or die "Bad lsi: $r : $_";
	    push(@ranks, $1);
	    push(@overlaps, $2);
	}

	$lsiranking{$conj} = [@ranks];
	$lsioverlap{$conj} = [@overlaps];	
    }

    close(LSI);

    return(\%lsiranking, \%lsioverlap, \@lsinames);
}



my %gkselectnmr = 
    (
     8 => [8],
     16 => [16],
     32 => [12,32,128],
     48 => [20,48,160,440],
     64 => [64,90],
     128 => [14,72],
     256 => [256],
     512 => [512]
    );

my %gkselectstd = 
    (
     8 => [8],
     16 => [16],
     32 => [32],
     48 => [48],
     64 => [64],
     128 => [128],
     256 => [],
     512 => []
);

my %gkselectlsi = 
    (
     8 => [8,32],
     16 => [16,64],
     32 => [12,32,128],
     48 => [48,160,440],
     64 => [64],
     128 => [128],
     256 => [256],
     512 => []
);


sub MakeLSIPredictions
{

    my ($conj,$filestem,$topicsnr,$iter,$allowed,$ref2fla,$manyknn,$minrefs,$lsiranking,$lsioverlap,$lsinames) = @_;

    my $distweight = 1; # use the similarity as a weight for aggregating the references

    my @knns = @{$lsiranking->{$conj}};   # the vector of knns sorted by their lsi-similarity
    my @overlap = @{$lsioverlap->{$conj}}; # the vector of the corresponding lsi-similarities

    my @res = ();
    foreach my $k (@$manyknn)
    {
	# hash of the aggregated refs of the @knns, with aggregated weights
	my %knnrefs = ();
	
	foreach my $n (0 .. $k-1)
	{
	    my $nb = $lsinames->[$knns[$n]];
	    my $refwght = ($distweight == 1)? $overlap[$n] : 1;
	    my @nbrefs = exists($minrefs->{$nb})?  ($nb, @{$minrefs->{$nb}}) : ($nb);
	    # my $nbrefs = $namerefs[$namenums{$nb}];
	    
	    foreach my $nbref (@nbrefs)   # (keys %$nbrefs)
	    {
		$knnrefs{$nbref} += $refwght # * $nbrefs->{$nbref};
	    }
	}    

	my @sortedrfs = sort { $knnrefs{$b} <=> $knnrefs{$a} } keys %knnrefs;

	my @refs1 = @sortedrfs;
	my @slices = @{$gkselectlsi{$k}};
	foreach my $s (@slices)
	{
	    open(F,">$MTMP/$conj/$conj.prob.lsi.w$topicsnr.k$k.s$s");
	    print F ('fof(', $conj, ',conjecture,', $ref2fla->{$conj});
	    my $i = 0; my $j = -1;
	    while(($i < $s) && ($j < $#refs1))
	    {
		$j++;
		if(exists($allowed->{$refs1[$j]}))
		{
		    $i++;
		    print F ('fof(', $refs1[$j], ',axiom,', $ref2fla->{$refs1[$j]});
		}
	    }
	    close(F);
	} 
    }
}



# prepare the test files used by knn 
sub PrepareKNNTest
{
    my ($filepath, $iter, $conj, $grefsyms, $greftrmstd, $greftrmnrm, $gstdnr, $gnrmnr) = @_;
    open(ALLFEATSTD,">$filepath.std") or die;
    open(ALLFEATNRM,">$filepath.nrm") or die;
    my $s = scalar(keys %$gstdnr);
    my $n = scalar(keys %$gnrmnr);
#	    my $syms = join(", ", @{$grefsyms->{$conj}});
#	    my $trmstd = join(", ", @{$greftrmstd->{$k}});
#	    my $trmnr = join(", ", @{$greftrmstd->{$k}});
    
    my $trmstd = join(", ", map {if(!exists($gstdnr->{$_})) {$gstdnr->{$_}=$s++}; $gstdnr->{$_} } @{$greftrmstd->{$conj}});
    my $trmnrm = join(", ", map {if(!exists($gnrmnr->{$_})) {$gnrmnr->{$_}=$n++}; $gnrmnr->{$_} } @{$greftrmnrm->{$conj}});
    
    print ALLFEATSTD ($conj,":",join(", ", (@{$grefsyms->{$conj}}, $trmstd)),"\n");
    print ALLFEATNRM ($conj,":",join(", ", (@{$grefsyms->{$conj}}, $trmnrm)),"\n");

    close(ALLFEATSTD);
    close(ALLFEATNRM);
}




sub MakeKNNPredictions
{
    my ($conj,$filestem,$weighting,$reflimit,$kind,$iter,$allowed,$ref2fla) = @_;
    my $features =   "$MTMP/$filestem.allfeat" . $kind . '_' . $iter;
    my @lines = `$MSCRIPT/knn.pl -w$weighting  -L$reflimit  -M10  -t\"$MTMP/$conj/$conj.test.$kind\"  $features  $MTMP/$filestem.allrefs_$iter 512:256:128:64:48:32:16:8 1 0 | tee $MTMP/$conj/$conj.pred.$kind$weighting`;

    my %sel = ($kind eq 'nrm')? %gkselectnmr : %gkselectstd;
    foreach $_ (@lines)
    {

	if(m/^ *KNN(\d+):([^:]+):(.*)/)
	{
	    my ($k,$c1,$rfs1) = ($1,$2,$3);
	    if($c1 ne $conj)
	    {
		mywarn "Missed conjecture: $c1 vs $conj\n";
	    }
	    else
	    {
		my @refs1 = split(/ +/,$rfs1);
		#my @refs1 = grep { exists($allowed->{$_}) } @refs0;
		my @slices = @{$sel{$k}};
		if(($#slices > -1) && ($weighting == 2))
		{
		    @slices = ($slices[0]);
		}
		foreach my $s (@slices)
		{
		    open(F,">$MTMP/$conj/$conj.prob.$kind.w$weighting.k$k.s$s");
		    print F ('fof(', $conj, ',conjecture,', $ref2fla->{$conj});
		    my $i = 0; my $j = -1;
		    while(($i < $s) && ($j < $#refs1))
		    {
			$j++;
			if(exists($allowed->{$refs1[$j]}))
			{
			    $i++;
			    print F ('fof(', $refs1[$j], ',axiom,', $ref2fla->{$refs1[$j]});
			}
		    }
		    close(F);
		} 
	    }
	}
    }
}




1;
