#!/usr/bin/python
#
# run as:
#
# perl -e 'while(<>) {s/^[^:]*://; s/,//g; push(@l,$_);} print $#l+1,"\n",@l;' mz4.allfeatnrm_0 > mz4.allfaa_gensim_0
# ./MkLSIRanks.py mz4.allfaa_gensim_0 1000 512 > mz4.allflsi1000_gensim_0
#
# needs gensim in the PYTHONPATH, e.g.:
#
# wget https://pypi.python.org/packages/source/g/gensim/gensim-0.8.6.tar.gz#md5=408405702f6541e07653711a7eb04a13
# tar xzf gensim-0.8.6.tar.gz
# export PYTHONPATH=`pwd`/gensim-0.8.6
#

import sys
from gensim import corpora, models, similarities, matutils

docs = sys.argv[1]
topicsnr = sys.argv[2]
reflimit = int(sys.argv[3])

# loads the file docs with space-separated features
# and the number of rows in the first line, and serially numbers
# the features
c3 = corpora.lowcorpus.LowCorpus(docs)

# saves the corpus in the MatrixMarket format
corpora.MmCorpus.serialize(docs+'.mm',c3)

# loads the MatrixMarket format, now it is a sparse matrix
mm = corpora.MmCorpus(docs+'.mm')

# "defines the lsi model", takes couple of seconds (for 1k topics, about 20-30s)
lsi = models.LsiModel(mm, num_topics=topicsnr)

# save it for future fast loading ( lsi = models.LsiModel.load(file) )
lsi.save(docs+'.'+str(topicsnr)+'.lsimodel')

# "transform corpus to LSI space and index it"
# runs lsi with 400 topics on mm; http://radimrehurek.com/gensim/tut3.html says:
# "For example, a corpus of 1M documents would require 2GB of RAM in a 256-dimensional LSI space"
index = similarities.MatrixSimilarity(lsi[mm])

# save the index future for fast loading ( index1 = similarities.MatrixSimilarity.load(file) )
index.save(docs+'.'+str(topicsnr)+'.lsiindex')

# this evaluates a new query if needed (eg with fast loading)
#lsivec=lsi[query]
#sim1 = index[lsivec]

# this takes about 10 seconds, and computes the similar docs for all docs
sims = index[lsi[mm]]




# write the similarities into a file, used later by weighted knn;
# takes tens of seconds and 46M
#f = open('ranks1.txt','w')
#for s in sims:
#    k1=sorted(enumerate(s), key=lambda item: -item[1])
#    print >>f, k1[:512]

#f.close()

for s in sims:
    k1=sorted(enumerate(s), key=lambda item: -item[1])
    print k1[:reflimit]

