package ProblemIO;

# Now mostly parsing of the LTB input file

use strict;
use Pod::Usage;
use Getopt::Long;
use IPC::Open2;
use File::Spec;


## downcase, translate nonalphanum chars to '_', add 'p' in the beginning
## if starting with '_' after that
sub MkTptpName
{
    my ($basename) = @_;
    $basename =~ tr/A-Z/a-z/; $basename =~ tr/a-zA-Z0-9_/_/c;
    if($basename =~ m/^_.*/) { $basename = 'p' . $basename; }
    return $basename;
}

sub DieIfDefined
{
  my ($item) = @_;
  die "Already defined: $item" if(defined($item));
}

sub ReadConfig
{
    my ($ltbfile) = @_;
    my ($execution_order, $output_required, $problem_limit, $overall_limit);

    my $readconfig = 1;

    # we start at:
    # % SZS start BatchConfiguration

    while(<$ltbfile>)
    {
      # execution.order ordered
      if(m/^\s*execution.order\s+(\S+)\s*/)
      {
	DieIfDefined($execution_order);
	$execution_order = $1;
      }

      # output.required Proof
      elsif(m/^\s*output.required\s+(\S+)\s*/)
      {
	DieIfDefined($output_required);
	$output_required = $1;
      }

      # limit.time.problem.wc 30
      elsif(m/^\s*limit.time.problem.wc\s+(\d+)\s*/)
      {
	DieIfDefined($problem_limit);
	$problem_limit = $1;
      }

      # limit.time.overall.wc 240
      elsif(m/^\s*limit.time.overall.wc\s+(\d+)\s*/)
      {
	DieIfDefined($overall_limit);
	$overall_limit = $1;
      }

      # % SZS end BatchConfiguration
      elsif(m/^\s*%\s*SZS\s+end\s+BatchConfiguration\s*/)
      {
	return ($execution_order, $output_required, $problem_limit, $overall_limit);
      }

      else { print "Unknown configuration entry: $_"; }
    }

    # we should never get here
    die "Wrong LTB input";
}

sub ReadOneBatch
{
    my ($ltbfile) = @_;

    my ($execution_order, $output_required, $problem_limit, $overall_limit);

    my $readprobs = 0;
    my $readincludes = 0;

    my @ltbprobnames = ();
    my %ltbprobsolutions = ();
    my %include_files = ();

    ($execution_order, $output_required, $problem_limit, $overall_limit)
      = ReadConfig($ltbfile);

    while(<$ltbfile>)
    {

      # % SZS start BatchIncludes
      if(m/^\s*%\s*SZS\s+start\s+BatchIncludes/)
      {
	$readincludes = 1;
      }
      if(m/^\s*%\s*SZS\s+end\s+BatchIncludes/)
      {
	$readincludes = 0;
      }

      # % SZS start BatchProblems
      if(m/^\s*%\s*SZS\s+start\s+BatchProblems/)
      {
	$readprobs = 1;
      }
      if(m/^\s*%\s*SZS\s+end\s+BatchProblems/)
      {
	$readprobs = 0;

	my $batch = [$execution_order, $output_required, $problem_limit,
		     $overall_limit, \%include_files, \@ltbprobnames,
		     \%ltbprobsolutions];
	return $batch;
      }

      # include('Axioms/HOL001+0.ax').
      if(($readincludes == 1) && m/^\s*include[(]\s*[']([^']+)[']\s*[)]\.\s*$/)
      {
	$include_files{$1} = ();
      }

      # no renaming now
      if(($readprobs == 1) && m/^\s*(\S+)\s+(\S+)\s*$/)
      {
	    my ($pname, $sname) = ($1,$2);
	    # die "$pname not readable!" unless(-e $pname);
	    $ltbprobsolutions{$pname} = $sname;
	    push(@ltbprobnames, $pname);

	    # my ($volume,$directories,$file) = File::Spec->splitpath( $pname );
	    # my $tptpname = MkTptpName($file);
	    # if($gconjnaming == 1)
	    # {
	    # 	$tptpname = `grep 'fof(.*, *conjecture[ ,]' $pname | sed -e 's/^.*fof( *\\([^ ,]*\\) *, *conjecture.*/\\1/'`;
	    # 	chomp($tptpname);
	    # }
	    # die "Non-unique TPTP-fied basenames not allowed: $file, $tptpname, $pname, $ltbprobnames{$file}->[0]"
	    # 	if(exists $ltbprobnames{$tptpname});
	    # $ltbprobnames{$tptpname} = [$pname, $sname];
       }
    }

    # we should never get here
    die "Wrong LTB input";

}


## test: perl -e 'use ProblemIO; ($category, $training_directory, $batches) = ProblemIO::ReadLTBData("BatchSampleLTBHOL"); print "$category,$training_directory\n"; foreach $bt (@$batches) {print $bt->[0],$bt->[1],$bt->[2],$bt->[3],join(",",keys %{$bt->[4]}),join(";",@{$bt->[5]}),join(",",keys %{$bt->[6]}),"\n"}'

## read the ltb file, retuning a triple ($category,
## $training_directory, \@batches) where each batch is:
## [$execution_order, $output_required, $problem_limit,
## $overall_limit, \%include_files, \@ltbprobnames,
## \%ltbprobsolutions];
sub ReadLTBData
{
    my ($ltbfilename) = @_;

    open(my $ltbfile, $ltbfilename) or die "$ltbfilename not readable";

    my ($category, $training_directory);

    my @batches = ();

    my %ltbprobnames = ();
    my %include_files = ();

    while(<$ltbfile>)
    {
      # division.category LTB.HOL
      if(m/^\s*division.category\s+(\S+)\s*/)
      {
	DieIfDefined($category);
	$category = $1;
      }

      # division.category.training_directory TrainingData.HOL
      elsif(m/^\s*division.category.training_directory\s+(\S+)\s*/)
      {
	DieIfDefined($training_directory);
	$training_directory = $1;
      }

      elsif(m/^\s*%\s*SZS\s+start\s+BatchConfiguration\s*/)
      {
	my $batch = ReadOneBatch($ltbfile);
	push(@batches, $batch);
      }

      else  { print "Unknown LTB entry: $_"; }

    }
    close($ltbfile);

    return ($category, $training_directory, \@batches);
}


1;
